@@ -17,12 +17,14 @@
 * ============================================================ */
 #include "gm_plugin.h"
 #include "gm_manager.h"
+#include "gm_script.h"
 #include "browserwindow.h"
 #include "webpage.h"
 #include "pluginproxy.h"
 #include "mainapplication.h"
 #include "tabwidget.h"
 #include "webtab.h"
+#include "webview.h"
 #include "../config.h"
 
 #include <QtWebEngineWidgetsVersion>
@@ -66,16 +68,49 @@ void GM_Plugin::showSettings(QWidget* parent)
     m_manager->showSettings(parent);
 }
 
+void GM_Plugin::populateWebViewMenu(QMenu* menu, WebView* view, const WebHitTestResult& r)
+{
+    Q_UNUSED(r)
+
+    if (m_manager->contextMenuScripts().isEmpty()) {
+        return;
+    }
+
+    const QUrl url = view->url();
+    QList<GM_Script*> matchingScripts;
+
+    auto contextMenuScripts = m_manager->contextMenuScripts();
+    for (const auto &script : std::as_const(contextMenuScripts)) {
+        if (script->match(url)) {
+            matchingScripts.append(script);
+        }
+    }
+
+    if (matchingScripts.isEmpty()) {
+        return;
+    }
+
+    auto* gmMenu = new QMenu(tr("GreaseMonkey"));
+    gmMenu->setIcon(QIcon(QSL(":gm/data/icon.svg")));
+
+    for (const auto &script : std::as_const(matchingScripts)) {
+        gmMenu->addAction(script->icon(), script->name(), this, [script, view]() {
+            view->page()->execJavaScript(script->webScript().sourceCode(), WebPage::SafeJsWorld);
+        });
+    }
+
+    menu->addMenu(gmMenu);
+}
+
 bool GM_Plugin::acceptNavigationRequest(WebPage *page, const QUrl &url, QWebEnginePage::NavigationType type, bool isMainFrame)
 {
     Q_UNUSED(page)
     Q_UNUSED(isMainFrame)
 
-    bool navigationType = type == QWebEnginePage::NavigationTypeLinkClicked || type == QWebEnginePage::NavigationTypeRedirect;
+    bool navigationType = type == QWebEnginePage::NavigationTypeLinkClicked;
 
-    if (navigationType && url.toString().endsWith(QLatin1String(".user.js"))) {
+    if (navigationType && url.fileName().endsWith(QLatin1String(".user.js"))) {
         m_manager->downloadScript(url);
-        return false;
     }
     return true;
 }
